/**
 * @license lucide-react v0.577.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createLucideIcon from '../createLucideIcon.js';

const __iconNode = [
  ["path", { d: "M10 12h11", key: "6m4ad9" }],
  ["path", { d: "m17 16 4-4-4-4", key: "iin4zf" }],
  [
    "path",
    {
      d: "M21 6.344V5a2 2 0 0 0-2-2H5a2 2 0 0 0-2 2v14a2 2 0 0 0 2 2h14a2 2 0 0 0 2-2v-1.344",
      key: "1ojbhp"
    }
  ]
];
const SquareArrowRightExit = createLucideIcon("square-arrow-right-exit", __iconNode);

export { __iconNode, SquareArrowRightExit as default };//# sourceMappingURL=https://main.vscode-cdn.net/sourcemaps/4f68242f732f9b2192d032188e523bb2149ef7a6/node_modules/lucide-react/dist/esm/icons/square-arrow-right-exit.js.map
