/**
 * @license lucide-react v0.577.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createLucideIcon from '../createLucideIcon.js';

const __iconNode = [
  ["path", { d: "m10 16 4-4-4-4", key: "w9835o" }],
  ["path", { d: "M3 12h11", key: "pmja8f" }],
  [
    "path",
    {
      d: "M3 8V5a2 2 0 0 1 2-2h14a2 2 0 0 1 2 2v14a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2v-3",
      key: "1bqs5q"
    }
  ]
];
const SquareArrowRightEnter = createLucideIcon("square-arrow-right-enter", __iconNode);

export { __iconNode, SquareArrowRightEnter as default };//# sourceMappingURL=https://main.vscode-cdn.net/sourcemaps/4f68242f732f9b2192d032188e523bb2149ef7a6/node_modules/lucide-react/dist/esm/icons/square-arrow-right-enter.js.map
