/*
 * 1DS JS SDK POST plugin, 3.2.18
 * Copyright (c) Microsoft and contributors. All rights reserved.
 * (Microsoft Internal Only)
 */
export {};
// export declare var XDomainRequest: {
//     prototype: IXDomainRequest;
//     new (): IXDomainRequest;
// };
//# sourceMappingURL=https://main.vscode-cdn.net/sourcemaps/4f68242f732f9b2192d032188e523bb2149ef7a6/node_modules/@microsoft/1ds-post-js/dist-esm/src/typings/XDomainRequest.js.map