"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || (function () {
    var ownKeys = function(o) {
        ownKeys = Object.getOwnPropertyNames || function (o) {
            var ar = [];
            for (var k in o) if (Object.prototype.hasOwnProperty.call(o, k)) ar[ar.length] = k;
            return ar;
        };
        return ownKeys(o);
    };
    return function (mod) {
        if (mod && mod.__esModule) return mod;
        var result = {};
        if (mod != null) for (var k = ownKeys(mod), i = 0; i < k.length; i++) if (k[i] !== "default") __createBinding(result, mod, k[i]);
        __setModuleDefault(result, mod);
        return result;
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
exports.Storage = void 0;
const vscode = __importStar(require("vscode"));
const fs = __importStar(require("node:fs/promises"));
const path = __importStar(require("node:path"));
const DEPLOYMENT_KEY = 'nicloud.deployment';
class Storage {
    constructor(ctx) {
        this.ctx = ctx;
    }
    getDeployment() {
        return this.ctx.globalState.get(DEPLOYMENT_KEY);
    }
    async setDeployment(deployment) {
        await this.ctx.globalState.update(DEPLOYMENT_KEY, deployment);
        await vscode.commands.executeCommand('setContext', 'nicloud.authenticated', true);
        await this._writeTokenFile(deployment.token);
    }
    async clearDeployment() {
        await this.ctx.globalState.update(DEPLOYMENT_KEY, undefined);
        await vscode.commands.executeCommand('setContext', 'nicloud.authenticated', false);
        await this._writeTokenFile('');
    }
    async _writeTokenFile(token) {
        const tokenPath = path.join(this.ctx.globalStorageUri.fsPath, 'session_token');
        try {
            await fs.mkdir(this.ctx.globalStorageUri.fsPath, { recursive: true });
            await fs.writeFile(tokenPath, token, { mode: 0o600 });
        }
        catch { /* best effort */ }
    }
    getSessionToken() {
        return this.getDeployment()?.token;
    }
    toSafeHostname(url) {
        try {
            const u = new URL(url);
            return u.hostname.replace(/\./g, '-');
        }
        catch {
            return url.replace(/[^a-zA-Z0-9-]/g, '-');
        }
    }
}
exports.Storage = Storage;
//# sourceMappingURL=storage.js.map