/**
 * @license lucide-react v0.577.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createLucideIcon from '../createLucideIcon.js';

const __iconNode = [
  ["path", { d: "M3 10A6.06 6.06 0 0 1 12 10 A6.06 6.06 0 0 0 21 10", key: "13lfmc" }],
  ["path", { d: "M6 3v12a6 6 0 0 0 12 0V3", key: "1jnivp" }]
];
const ZodiacOphiuchus = createLucideIcon("zodiac-ophiuchus", __iconNode);

export { __iconNode, ZodiacOphiuchus as default };//# sourceMappingURL=https://main.vscode-cdn.net/sourcemaps/4f68242f732f9b2192d032188e523bb2149ef7a6/node_modules/lucide-react/dist/esm/icons/zodiac-ophiuchus.js.map
