"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseUndefinedDef = void 0;
function parseUndefinedDef() {
    return {
        not: {},
    };
}
exports.parseUndefinedDef = parseUndefinedDef;//# sourceMappingURL=https://main.vscode-cdn.net/sourcemaps/4f68242f732f9b2192d032188e523bb2149ef7a6/node_modules/openai/_vendor/zod-to-json-schema/parsers/undefined.js.map