"use strict";
Object.defineProperty(exports, "__esModule", { value: true });//# sourceMappingURL=https://main.vscode-cdn.net/sourcemaps/4f68242f732f9b2192d032188e523bb2149ef7a6/node_modules/font-ligatures/dist/types.js.map